@@ -1,4 +1,4 @@
-/* $Id: command.h,v 1.30 2004/07/18 20:33:55 bdejean Exp $ */
+/* $Id: command.h,v 1.32 2005/01/10 08:43:04 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -57,8 +57,10 @@ G_BEGIN_DECLS
 #define GLIBTOP_CMND_FSUSAGE		21
 #define GLIBTOP_CMND_NETLOAD		22
 #define GLIBTOP_CMND_PPP		23
+#define GLIBTOP_CMND_NETLIST		24
+#define GLIBTOP_CMND_PROC_OPEN_FILES	25
 
-#define GLIBTOP_MAX_CMND		24
+#define GLIBTOP_MAX_CMND		26
 
 #define _GLIBTOP_PARAM_SIZE		16
 
