@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.29 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: swap.c,v 1.31 2005/12/12 09:38:11 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
@@ -67,9 +68,9 @@ static struct nlist nlst [] = {
 };
 #endif
 
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 
-#if (__NetBSD_Version__ >= 104000000)
+#if (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 #include <uvm/uvm_extern.h>
 #include <sys/swap.h>
 #else
@@ -78,7 +79,7 @@ static struct nlist nlst [] = {
 
 #endif
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 static int mib_uvmexp [] = { CTL_VM, VM_UVMEXP };
 #else
 /* nlist structure for kernel access */
@@ -109,7 +110,7 @@ glibtop_init_swap_p (glibtop *server)
 #endif
 #endif
 
-#if !(defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000))
+#if !(defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)) && !defined(__OpenBSD__)
 	if (kvm_nlist (server->machine.kd, nlst2) < 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (cnt)");
 		return;
@@ -149,14 +150,14 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 #elif defined(__bsdi__)
 	struct swapstats swap;
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 	struct swapent *swaplist;
 #endif
 
 	int nswap, i;
 	int avail = 0, inuse = 0;
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	struct uvmexp uvmexp;
 	size_t length_uvmexp;
 #else
@@ -173,7 +174,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	if (server->sysdeps.swap == 0)
 		return;
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	length_uvmexp = sizeof (uvmexp);
 	if (sysctl (mib_uvmexp, 2, &uvmexp, &length_uvmexp, NULL, 0)) {
 		glibtop_warn_io_r (server, "sysctl (uvmexp)");
@@ -197,7 +198,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		buf->pagein = vmm.v_swappgsin - swappgsin;
 		buf->pageout = vmm.v_swappgsout - swappgsout;
 #else
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 		buf->pagein = uvmexp.swapins - swappgsin;
 		buf->pageout = uvmexp.swapouts - swappgsout;
 #else
@@ -211,7 +212,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
         swappgsin = vmm.v_swappgsin;
 	swappgsout = vmm.v_swappgsout;
 #else
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	swappgsin = uvmexp.swapins;
 	swappgsout = uvmexp.swapouts;
 #else
@@ -391,7 +392,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 	buf->total = swap.swap_total;
 
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 
 	nswap = swapctl (SWAP_NSWAP, NULL, 0);
 	if (nswap < 0) {
