@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.13 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: swap.c,v 1.16 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,11 +21,12 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
 
-static unsigned long _glibtop_sysdeps_swap =
+static const unsigned long _glibtop_sysdeps_swap =
 (1L << GLIBTOP_SWAP_TOTAL) + (1L << GLIBTOP_SWAP_USED) +
 (1L << GLIBTOP_SWAP_FREE);
 
@@ -50,7 +51,7 @@ glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 	memset (buf, 0, sizeof (glibtop_swap));
 
 	i = 0;
-	
+
 	while (table (TBL_SWAPINFO, i, (char *) &swapinfo, 1,
 		      sizeof (struct tbl_swapinfo)) > 0) {
 		buf->total += swapinfo.size * getpagesize ();
@@ -59,6 +60,6 @@ glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 	}
 
 	buf->flags = _glibtop_sysdeps_swap;
-	
+
 	buf->used  = buf->total - buf->free;
 }
